<?php
    /**
     * Sample implementation of the Custom Header feature.
     *
     * You can add an optional custom header image to header.php like so ...
     *
     *
     * @link http://codex.wordpress.org/Custom_Headers
     *
     * @package Ocin Lite
     */

    /**
     * Set up the WordPress core custom header feature.
     *
     * @uses ocin_lite_header_style()
     */
    function ocin_lite_custom_header_setup() {
        add_theme_support( 'custom-header', apply_filters( 'ocin_lite_custom_header_args', array(
            'default-image'      => '',
            'default-text-color' => '383838',
            'width'              => 1905,
            'height'             => 73,
            'flex-height'        => true,
            'flex-width'         => true,
            'wp-head-callback'   => 'ocin_lite_header_style',
        ) ) );
    }
    add_action( 'after_setup_theme', 'ocin_lite_custom_header_setup' );

    if ( ! function_exists( 'ocin_lite_header_style' ) ):
        /**
         * Styles the header image and text displayed on the blog
         *
         * @see ocin_lite_custom_header_setup().
         */
        function ocin_lite_header_style() {
            $header_text_color = get_header_textcolor();

            /*
             * If no custom options for text are set, let's bail.
             * get_header_textcolor() options: Any hex value, 'blank' to hide text. Default: add_theme_support( 'custom-header' ).
             */
            if ( get_theme_support( 'custom-header', 'default-text-color' ) === $header_text_color ) {
                return;
            }

        // If we get this far, we have custom styles. Let's do this. ?>
			<style type="text/css">
			<?php
                    // Has the text been hidden?
                        if ( ! display_header_text() ):
                    ?>
				.logo_container .ql_logo {
					position: absolute;
					clip: rect(1px, 1px, 1px, 1px);
				}
			<?php
                    // If the user has set a custom color for the text use that.
                    else:
                ?>
		.logo_container .ql_logo {
			color: #<?php echo esc_attr( $header_text_color ); ?>;
		}
		#primary-menu a {
			color: #<?php echo esc_attr( $header_text_color ); ?>;
			opacity: 0.8;
		}
	<?php endif; ?>
	</style>
	<?php
        }
    endif; // ocin_lite_header_style
